__title__ = "phoneutria"
__author__ = "Juan Bindez"
__license__ = "GPLv2 License"
__js__ = None
__js_url__ = None

import os

from phoneutria.version import __version__
from phoneutria.__main__ import Chelicera


import argparse

from phoneutria.__main__ import Chelicera
from phoneutria.google_hacking import google_search


def main():
    parser = argparse.ArgumentParser(description="Script to test webservers with GET and POST requests.")
    parser.add_argument("-t", "--url", help="URL of the webservice")
    parser.add_argument("-w", nargs="+", help="Extract specific data from the response (only for GET requests)")
    parser.add_argument("-l", "--links", help="get links in html")
    parser.add_argument("-gh", nargs="+", help="google_hacking")

    args = parser.parse_args()

    if args.w:
        ch = Chelicera(args.url)
        ch.make_get_words(args.w)

    elif args.links:
        ch = Chelicera(args.url)
        ch.make_get_links()

    elif args.gh:
        text = str(args.gh)
        print(text)
        query = "intitle:\"Index of\" inurl:" + text
        google_search(query)


if __name__ == "__main__":
    main()


# this is part of the phoneutria project.
#
# Copyright ©  2024  Juan Bindez  <juanbindez780@gmail.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,


import re
import requests
import json


class Chelicera:
    def __init__(self, url):
        self.url = url

    def make_get_words(self, target_word):
        word = str(target_word)
        response = requests.get(self.url)

        if response.status_code == 200:
            
            occurrences = re.findall(word, response.text, flags=re.IGNORECASE)

            for occurrence in occurrences:
                print(f'Occurrence of the word "{target_word}": {occurrence.start()}')
        else:
            print(f"Request failed with status code {response.status_code}")

        
            
    def make_get_links(self):
        response = requests.get(self.url)

        if response.status_code == 200:
            links = re.findall(r'<a href="(.*?)".*?>(.*?)</a>', response.text)

            for link in links:
                url, text = link
                print(f'Link: {url} - Text: {text}')
        else:
            print(f"Request failed with status code {response.status_code}")
                


from googlesearch import search

def google_search(query, num_results=15):
    try:
        results = search(query, num_results=num_results)

        for i, result in enumerate(results, 1):
            print("phoneutria")
            print(f"{i}. {result}")

    except Exception as e:
        print("phoneutria\n")
        print(f"Error performing the search: {e}")
